snake-guice is a simple, lightweight Python dependency injection framework
based on google-guice. The Guice way of doing things is quite a bit different
than the current breed of XML IoC containers.

This is experimental code. APIs will likely change and implementation will
definitely change.

See the `main project website <http://snake-guice.googlecode.com>`_ for
more information.
